@@ -18,6 +18,10 @@ CRM_LICENCA_ENDPOINT = {
     "licenca": {
         "resource": "/backend/licencas/{codigo}/",
         "methods": ["GET"],
+    },
+    "licenca_patch": {
+        "resource": "/backend/licencas/{codigo}/",
+        "methods": ["PATCH"],
     }
 }
 JOGO_SELF = {
